summaryrefslogtreecommitdiff
path: root/alembic
diff options
context:
space:
mode:
Diffstat (limited to 'alembic')
-rw-r--r--alembic/config.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/alembic/config.py b/alembic/config.py
index d9dbca9..30f3d79 100644
--- a/alembic/config.py
+++ b/alembic/config.py
@@ -51,13 +51,13 @@ class Config(object):
..versionadded:: 0.4
:param cfg_vars: A dictionary of keys and values that will be used
for substitution in the alembic config file.
"""
def __init__(self, file_=None, ini_section='alembic', output_buffer=None,
- stdout=sys.stdout, cmd_opts=None, cfg_vars = {}):
+ stdout=sys.stdout, cmd_opts=None, config_args = {}):
"""Construct a new :class:`.Config`
"""
@@ -66,7 +66,7 @@ class Config(object):
self.output_buffer = output_buffer
self.stdout = stdout
self.cmd_opts = cmd_opts
- self.cfg_vars = cfg_vars
+ self.config_args = config_args
cmd_opts = None
"""The command-line options passed to the ``alembic`` script.
@@ -117,8 +117,8 @@ class Config(object):
here = os.path.abspath(os.path.dirname(self.config_file_name))
else:
here = ""
- self.cfg_vars['here'] = here
- file_config = SafeConfigParser(self.cfg_vars)
+ self.config_args['here'] = here
+ file_config = SafeConfigParser(self.config_args)
if self.config_file_name:
file_config.read([self.config_file_name])
else:
@@ -51,13 +51,13 @@ class Config(object):
..versionadded:: 0.4
- :param cfg_vars: A dictionary of keys and values that will be used
+ :param config_args: A dictionary of keys and values that will be used
for substitution in the alembic config file.
"""